@@ -1,6 +1,7 @@
 import json
 from calendar import timegm
-import datetime
+from datetime import datetime
+import datetime as datetime2
 from json.encoder import encode_basestring_ascii, encode_basestring
 
 import django
@@ -28,9 +29,9 @@ def dateTimeEncoderEncode(self, o):
             chunks = list(chunks)
         return ''.join(chunks)
 
-    if isinstance(o, datetime.datetime):
+    if isinstance(o, datetime2.datetime):
         return o.strftime('%Y-%m-%d %H:%M:%S')
-    elif isinstance(o, datetime.date):
+    elif isinstance(o, datetime2.date):
         return o.strftime('%Y-%m-%d')
     return encode(self, o)
 
